==> libreoffice-calc-3.3.2.2.tar.bz2: libreoffice-calc-3.3.2.2/sc/source/ui/app/template.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sc.hxx"



#include "template.hxx"

//------------------------------------------------------------------------

ScTemplateDlg::ScTemplateDlg(Window * pParent, USHORT nAppResource) :
//  SfxTemplateDlg( pParent, nAppResource )
    SfxTemplateDialog( pParent )
{
}

//------------------------------------------------------------------------

__EXPORT ScTemplateDlg::~ScTemplateDlg()
{
}

//------------------------------------------------------------------------

BOOL ScTemplateDlg::New(String &rNewName)
{
    return TRUE;
}


void ScTemplateDlg::Edit(const String &)
{
}


BOOL ScTemplateDlg::Delete(const String &)
{
    return TRUE;
}


void ScTemplateDlg::InvalidateTemplates()
{
}


void ScTemplateDlg::ToggleApplyTemplate()
{
}




/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-calc-3.4.5.2.tar.bz2: libreoffice-calc-3.4.5.2/sc/source/ui/app/template.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sc.hxx"



#include "template.hxx"

//------------------------------------------------------------------------

ScTemplateDlg::ScTemplateDlg(Window * pParent, sal_uInt16 nAppResource) :
//  SfxTemplateDlg( pParent, nAppResource )
    SfxTemplateDialog( pParent )
{
}

//------------------------------------------------------------------------

ScTemplateDlg::~ScTemplateDlg()
{
}

//------------------------------------------------------------------------

sal_Bool ScTemplateDlg::New(String &rNewName)
{
    return sal_True;
}


void ScTemplateDlg::Edit(const String &)
{
}


sal_Bool ScTemplateDlg::Delete(const String &)
{
    return sal_True;
}


void ScTemplateDlg::InvalidateTemplates()
{
}


void ScTemplateDlg::ToggleApplyTemplate()
{
}




/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
